@@ -6,7 +6,7 @@ from bs4 import BeautifulSoup
 from dataclasses import dataclass
 from typing import Union
 
-from .config import config
+from .config import Config
 from .colors import colors
 
 options = [
@@ -117,7 +117,7 @@ def read_json(path):
 
         except FileNotFoundError:
             try:
-                config.user_files_path.mkdir(exist_ok=True)
+                Config().user_files_path.mkdir(exist_ok=True)
                 path.touch(exist_ok=True)
                 # avoids error on empty json file
                 with path.open("a") as f:
